@@ -69,12 +69,20 @@ def create_cookie(
         if isinstance(expires, datetime):
             kwargs["expires"] = expires.timestamp()
         elif isinstance(expires, str):
-            kwargs["expires"] = timegm(strptime(expires, "%a, %d-%b-%Y %H:%M:%S GMT"))
+            try:
+                if len(expires) < 29:
+                    kwargs["expires"] = timegm(strptime(expires, "%a, %d-%b-%y %H:%M:%S GMT"))
+                else:
+                    kwargs["expires"] = timegm(strptime(expires, "%a, %d-%b-%Y %H:%M:%S GMT"))
+            except ValueError:
+                pass
     elif max_age := kwargs.get("max-age"):
         try:
-            kwargs["expires"] = int(time()) + int(max_age)
+            max_age = int(max_age)
         except ValueError:
             raise TypeError(f"max-age: {max_age!r} must be integer")
+        if max_age >= 0:
+            kwargs["expires"] = int(time()) + max_age
     result: dict[str, Any] = {
         "version": 0, 
         "name": name, 
@@ -275,12 +283,20 @@ def morsel_to_cookie(cookie: Morsel, /) -> Cookie:
         if isinstance(expires, datetime):
             expires = expires.timestamp()
         elif isinstance(expires, str):
-            expires = timegm(strptime(expires, "%a, %d-%b-%Y %H:%M:%S GMT"))
+            try:
+                if len(expires) < 29:
+                    expires = timegm(strptime(expires, "%a, %d-%b-%y %H:%M:%S GMT"))
+                else:
+                    expires = timegm(strptime(expires, "%a, %d-%b-%Y %H:%M:%S GMT"))
+            except ValueError:
+                expires = None
     elif max_age := cookie.get("max-age"):
         try:
-            expires = int(time()) + int(max_age)
+            expires = int(max_age)
         except ValueError:
             raise TypeError(f"max-age: {max_age} must be integer")
+        if max_age >= 0:
+            expires = int(time()) + max_age
     return create_cookie(
         comment=cookie["comment"], 
         comment_url=bool(cookie["comment"]), 
@@ -312,7 +328,7 @@ def cookies_to_dict(
                 return True
             if (domain := getattr(cookie, "domain", "")) and not domain.endswith(urlp.netloc):
                 return False
-            if (url_path := urlp.path) and commonpath((url_path, (path := (getattr(cookie, "path", "") or "")))) != url_path:
+            if (url_path := urlp.path) and commonpath((url_path, getattr(cookie, "path", "") or "")) != url_path:
                 return False
             return True
     elif isinstance(predicate, Container):
@@ -373,7 +389,7 @@ def cookies_to_str(
                 return True
             if (domain := getattr(cookie, "domain", "")) and not domain.endswith(urlp.netloc):
                 return False
-            if (url_path := urlp.path) and commonpath((url_path, (path := (getattr(cookie, "path", "") or "")))) != url_path:
+            if (url_path := urlp.path) and commonpath((url_path, getattr(cookie, "path", "") or "")) != url_path:
                 return False
             return True
     elif isinstance(predicate, Container):
